@@ -13,15 +13,12 @@ if not 'S3_BUCKET' in os.environ:
 
 if not 'LOG_STREAMNAME' in os.environ:    
     os.environ['LOG_STREAMNAME'] = 'deepportfolio-logs'
-
-if not 'LOG_PROFILENAME' in os.environ:    
-    os.environ['LOG_PROFILENAME'] = 'kinesis-logs-write-only'
-
-if not 'REALTIME_PROFILENAME' in os.environ:    
-    os.environ['REALTIME_PROFILENAME'] = 'kinesis-logs-write-only'
-
+    
 if not 'BASE_STREAM_NAME' in os.environ:    
-    os.environ['BASE_STREAM_NAME'] = 'deepportfolio-real-time'
+    os.environ['BASE_STREAM_NAME'] = 'deepportfolio-real-time'    
+
+if not 'AWS_PROFILENAME' in os.environ:
+    os.environ['AWS_PROFILENAME'] = 'guest'
 
 os.environ['USER_COMPUTER'] = os.environ['USERNAME']+'@'+os.environ['COMPUTERNAME']
 
