@@ -43,9 +43,9 @@ class KinesisLogStreamHandler(logging.StreamHandler):
                     'asctime': asctime,
                     'logger_name': record.name,
                     'level': record.levelname,
-                    'message': record.msg.replace('\'','\"'),
-                    'function_name': record.funcName,
-                    'file_name': record.filename,                
+                    'message': str(record.msg).replace('\'','\"'),
+                    #'function_name': record.funcName,
+                    #'file_name': record.filename,                
                 }   
             msg = json.dumps(msg)
             if self.datastream:
@@ -162,7 +162,7 @@ class KinesisLogStreamConsumer():
                             if not logfilepath.parents[0].is_dir():
                                 os.makedirs(logfilepath.parents[0])
                             with open(logfilepath,'a+',encoding = 'utf-8') as f:
-                                f.write(line+'\n')  
+                                f.write(line.replace('\n',' ').replace('\r',' ')+'\n')  
                         except Exception as e:
                             print('Invalid record:'+str(rec))
                             print('Invalid record error:'+str(e))
