@@ -3,6 +3,7 @@ import pandas as pd
 import numpy as np
 from datetime import datetime, timedelta
 from pathlib import Path
+from pandas.tseries.offsets import BDay
 
 
 from SharedData.Logger import Logger
@@ -69,7 +70,7 @@ class SharedDataPeriod:
 
     def getTimeIndex(self, startDate):
         if not startDate in self.timeidx.keys():
-            nextsaturday = datetime.today()\
+            nextsaturday = datetime.today() + BDay(1)\
                 + timedelta((12 - datetime.today().weekday()) % 7)
                         
             if self.period=='D1':
